wsql_sdk.syntax package — WSQL-SDK 0.2.1 documentation

# wsql_sdk.syntax package

## Submodules

## wsql_sdk.syntax.asio module

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

## wsql_sdk.syntax.pyaio module

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

`wsql_sdk.syntax.pyaio.` `body_close`()

  close the main logic

`wsql_sdk.syntax.pyaio.` `body_open`()

  open the main logic

`wsql_sdk.syntax.pyaio.` `cursor_close`()

  close cursor

`wsql_sdk.syntax.pyaio.` `cursor_open`()

  open cursor

`wsql_sdk.syntax.pyaio.` `procedure_call`(name, args)

  call procedure

`wsql_sdk.syntax.pyaio.` `procedure_close`()

  close procedure body

`wsql_sdk.syntax.pyaio.` `procedure_open`(name, args)

  open procedure body

`wsql_sdk.syntax.pyaio.` `temporary_table`(name, columns)

  create a temporary table

`wsql_sdk.syntax.pyaio.` `transaction_close`()

  close transaction scope

`wsql_sdk.syntax.pyaio.` `transaction_open`()

  open transaction scope

## wsql_sdk.syntax.pynative module

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

`wsql_sdk.syntax.pynative.` `body_close`()

  close the main logic

`wsql_sdk.syntax.pynative.` `body_open`()

  open the main logic

`wsql_sdk.syntax.pynative.` `cursor_close`()

  close cursor

`wsql_sdk.syntax.pynative.` `cursor_open`()

  open cursor

`wsql_sdk.syntax.pynative.` `procedure_call`(name, args)

  call procedure

`wsql_sdk.syntax.pynative.` `procedure_close`()

  close procedure body

`wsql_sdk.syntax.pynative.` `procedure_open`(name, args)

  open procedure body

`wsql_sdk.syntax.pynative.` `temporary_table`(name, columns)

  create a temporary table

`wsql_sdk.syntax.pynative.` `transaction_close`()

  close transaction scope

`wsql_sdk.syntax.pynative.` `transaction_open`()

  open transaction scope

## Module contents

This file is part of WSQL-SDK

The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.